@@ -1,129 +1,19 @@
 import shioaji as sj
 import typing
-from .core import Base
 from pydantic import StrictInt
 from functools import partial
-from enum import Enum
-
-
-class Trend(str, Enum):
-    Up = "Up"
-    Down = "Down"
-    Equal = "Equal"
-
-
-class PriceType(str, Enum):
-    LimitPrice = "LimitPrice"  # 限價
-    LimitUp = "LimitUp"  # 漲停
-    Unchanged = "Unchanged"  # 平盤
-    LimitDown = "LimitDown"  # 跌停
-
-
-class PriceGap(Base):
-    price: float
-    trend: Trend
-
-
-class Price(PriceGap):
-    price: float = 0.0
-    trend: Trend = Trend.Equal
-    price_type: PriceType = PriceType.LimitPrice
-
-    def __init__(
-        self,
-        price: float = 0.0,
-        trend: Trend = Trend.Equal,
-        price_type: PriceType = PriceType.LimitPrice,
-    ):
-        super().__init__(**dict(trend=trend, price=price, price_type=price_type))
-
-
-class QtyGap(Base):
-    qty: int
-    trend: Trend
-
-
-class Qty(QtyGap):
-    trend: Trend = Trend.Equal
-
-    def __init__(self, qty: int, trend: Trend = Trend.Equal):
-        super().__init__(**dict(qty=qty, trend=trend))
-
-
-class TouchCmd(Base):
-    code: str
-    close: Price = None
-    buy_price: Price = None
-    sell_price: Price = None
-    high: Price = None
-    low: Price = None
-    volume: Qty = None
-    total_volume: Qty = None
-
-    def __init__(
-        self,
-        code: str,
-        close: Price = None,
-        buy_price: Price = None,
-        sell_price: Price = None,
-        high: Price = None,
-        low: Price = None,
-        volume: Qty = None,
-        total_volume: Qty = None,
-    ):
-        super().__init__(
-            **dict(
-                code=code,
-                close=close,
-                buy_price=buy_price,
-                sell_price=sell_price,
-                high=high,
-                low=low,
-                volume=volume,
-                total_volume=total_volume,
-            )
-        )
-
-
-class OrderCmd(Base):
-    code: str
-    order: sj.order.Order
-
-    def __init__(self, code: str, order: sj.order.Order):
-        super().__init__(**dict(code=code, order=order))
-
-
-class TouchOrderCond(Base):
-    touch_cmd: TouchCmd
-    order_cmd: OrderCmd
-
-    def __init__(self, touch_cmd: TouchCmd, order_cmd: OrderCmd):
-        super().__init__(**dict(touch_cmd=touch_cmd, order_cmd=order_cmd))
-
-
-class StoreCond(Base):
-    close: PriceGap = None
-    buy_price: PriceGap = None
-    sell_price: PriceGap = None
-    high: PriceGap = None
-    low: PriceGap = None
-    volume: QtyGap = None
-    total_volume: QtyGap = None
-    order_contract: sj.contracts.Contract
-    order: sj.Order
-    excuted: bool = False
-
-
-class StatusInfo(Base):
-    close: float
-    buy_price: float
-    sell_price: float
-    high: float
-    low: float
-    change_price: float  # 漲跌
-    change_rate: float  # 幅度
-    volume: int
-    total_volume: int
+from touchprice.constant import Trend, PriceType
+from touchprice.condition import (
+    Price,
+    TouchOrderCond,
+    OrderCmd,
+    TouchCmd,
+    StoreCond,
+    PriceGap,
+    StatusInfo,
+    Qty,
+    QtyGap,
+)
 
 
 def get_contracts(api: sj.Shioaji):
@@ -135,7 +25,7 @@ def get_contracts(api: sj.Shioaji):
     return contracts
 
 
-class TouchOrder:
+class TouchOrderExecutor:
     def __init__(self, api: sj.Shioaji):
         self.api: sj.Shioaji = api
         self.conditions: typing.Dict[str, typing.List[StoreCond]] = {}
@@ -166,12 +56,14 @@ class TouchOrder:
         if tconds_dict:
             for key, value in tconds_dict.items():
                 if key not in ["volume", "total_volume"]:
-                    tconds_dict[key] = TouchOrder.set_price(Price(**value), contract)
+                    tconds_dict[key] = TouchOrderExecutor.set_price(
+                        Price(**value), contract
+                    )
             tconds_dict["order_contract"] = self.contracts[condition.order_cmd.code]
             tconds_dict["order"] = condition.order_cmd.order
             return StoreCond(**tconds_dict)
 
-    def set_condition(self, condition: TouchOrderCond):
+    def add_condition(self, condition: TouchOrderCond):
         code = condition.touch_cmd.code
         touch_contract = self.contracts[code]
         self.update_snapshot(touch_contract)
@@ -219,14 +111,19 @@ class TouchOrder:
                     cond.pop("order")
                     cond.pop("order_contract")
                     cond.pop("excuted")
+                    cond.pop("result")
                     if all(
                         self.touch_cond(value, info[key]) for key, value in cond.items()
                     ):
                         self.conditions[code][num].excuted = True
-                        self.api.place_order(order_contract, order)
+                        self.api.place_order(
+                            order_contract, order, cb=self.conditions[code][num].result
+                        )
 
     def integration(self, topic: str, quote: dict):
-        if topic.startswith("MKT/") or topic.startswith("L/"):
+        if "Simtrade" in quote.keys():
+            pass
+        elif topic.startswith("MKT/") or topic.startswith("L/"):
             code = topic.split("/")[-1]
             if code in self.infos.keys():
                 info = self.infos[code]
